==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingStrategyDescription } from "./WebSortingStrategyDescription";
/**
 * @hidden
 */
var WebSortingStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSortingStrategyDescriptionMetadata, _super);
    function WebSortingStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingStrategyDescriptionMetadata.b = function (a) {
        if (WebSortingStrategyDescriptionMetadata.a == null) {
            WebSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingStrategyDescriptionMetadata.c(WebSortingStrategyDescriptionMetadata.a);
        }
        if (a.j(WebSortingStrategyDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSortingStrategyDescriptionMetadata.a);
    };
    WebSortingStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebSortingStrategyDescriptionMetadata.d = function (a) {
        WebSortingStrategyDescriptionMetadata.b(a);
        a.aa("WebSortingStrategy", function () { return new WebSortingStrategyDescription(); });
        a.z("WebSortingStrategy", WebSortingStrategyDescriptionMetadata.a);
    };
    WebSortingStrategyDescriptionMetadata.$t = markType(WebSortingStrategyDescriptionMetadata, 'WebSortingStrategyDescriptionMetadata');
    WebSortingStrategyDescriptionMetadata.a = null;
    return WebSortingStrategyDescriptionMetadata;
}(Base));
export { WebSortingStrategyDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSortingStrategyDescription } from "./WebSortingStrategyDescription";
/**
 * @hidden
 */
var WebSortingStrategyDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebSortingStrategyDescriptionMetadata, _super);
    function WebSortingStrategyDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSortingStrategyDescriptionMetadata.b = function (a) {
        if (WebSortingStrategyDescriptionMetadata.a == null) {
            WebSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSortingStrategyDescriptionMetadata.c(WebSortingStrategyDescriptionMetadata.a);
        }
        if (a.k(WebSortingStrategyDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSortingStrategyDescriptionMetadata.a);
    };
    WebSortingStrategyDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SortingStrategy");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebSortingStrategyDescriptionMetadata.d = function (a) {
        WebSortingStrategyDescriptionMetadata.b(a);
        a.ac("WebSortingStrategy", function () { return new WebSortingStrategyDescription(); });
        a.ab("WebSortingStrategy", WebSortingStrategyDescriptionMetadata.a);
    };
    WebSortingStrategyDescriptionMetadata.$t = markType(WebSortingStrategyDescriptionMetadata, 'WebSortingStrategyDescriptionMetadata');
    WebSortingStrategyDescriptionMetadata.a = null;
    return WebSortingStrategyDescriptionMetadata;
}(Base));
export { WebSortingStrategyDescriptionMetadata };
